#!/usr/bin/env python3
import os
import csv
import sys
import datetime as dt

from piranha.utils.log_colours import green,cyan
from piranha.utils.config import *

def add_col_to_metadata(new_column_name, new_column_dict, metadata, new_metadata, match_column, config): 
    #dictionary currently is key=sequence name and value=new col value
    print(green("Adding column to master metadata:"), new_column_name)
    with open(new_metadata, 'w') as fw:
        
        with open(metadata,"r") as f:
            reader = csv.DictReader(f)
            header = reader.fieldnames
            header.append(new_column_name)
            config[KEY_QUERY_CSV_HEADER] = header
            
            writer = csv.DictWriter(fw, fieldnames=config[KEY_QUERY_CSV_HEADER],lineterminator='\n')
            writer.writeheader()

            for row in reader:
                new_row = row

                if new_row[match_column] in new_column_dict:
                    new_row[new_column_name] = new_column_dict[new_row[match_column]]
                else:
                    new_row[new_column_name] = ""

                writer.writerow(new_row)

def check_date_format(to_check, line_count, header):

    date_format = "%Y-%m-%d"
    
    try:
        dt.datetime.strptime(to_check, date_format).date()
    except:
        sys.stderr.write(cyan(f'Date {to_check} on line {line_count} in column {header} in incorrect format. Please use YYYY-MM-DD\n'))
        sys.exit(-1)
                
def add_arg_to_config(key,arg,config):
    if arg:
        config[key] = arg

def add_file_to_config(key,arg,config):
    if arg:
        path_to_file = os.path.abspath(config["cwd"])
        full_path = os.path.join(path_to_file,arg)
        config[key]=full_path

def add_path_to_config(key,arg,config):
    if arg:
        expanded_path = os.path.expanduser(arg)
        path_to_cwd = os.path.abspath(config["cwd"])
        full_path = os.path.join(path_to_cwd,expanded_path)
        config[key]=full_path

def check_path_exists(path):
    if not os.path.exists(path):
        sys.stderr.write(cyan(f"Error: path {path} does not exist. Check input.\n"))
        sys.exit(-1)



def header(v):
    print(green("""\n
                            __                      __            
                    ______ |__|_____ _____  |\____ |  |__ _____   
                    \____ \|  |\  _ \\\__  \ |     \|  |  \\\__  \  
                    |  |_| |  ||  |\/ / __ \|   |  \   |  \/ __ \ 
                    |   __/|__||__|  (____ / ___|__/___|___(____/ 
                    |__|                                          

                     **** Poliovirus Investigation Resource ****
                   **** Automating Nanopore Haplotype Analysis ****
                """)+green(f"""
                                        {v}""")+green("""
                        ****************************************
                                                                
                       Aine O'Toole, Rachel Colquhoun, Corey Ansley, 
                                    Andrew Rambaut        
                                 Edinburgh University          
\n"""))

def preamble(v):
    header(v)
    
